import { PluginFunction, DocumentFile } from 'graphql-codegen-core';
import { GraphQLSchema } from 'graphql';
export * from './helpers';
export interface TypeScriptNamingConventionMap {
    default?: string | Function;
    enumValues?: string | Function;
    typeNames?: string | Function;
}
export interface TypeScriptCommonConfig {
    namingConvention?: string | TypeScriptNamingConventionMap;
    avoidOptionals?: boolean;
    optionalType?: string;
    constEnums?: boolean;
    enumsAsTypes?: boolean;
    immutableTypes?: boolean;
    interfacePrefix?: string;
    enums?: {
        [enumName: string]: {
            [valueName: string]: string;
        } | string | null;
    };
    scalars?: {
        [scalarName: string]: string;
    };
}
export declare const DEFAULT_SCALARS: {
    String: string;
    Int: string;
    Float: string;
    Boolean: string;
    ID: string;
};
export declare function initCommonTemplate(hbs: any, schema: any, documents: DocumentFile[], config: TypeScriptCommonConfig): {
    templateContext: {
        config: TypeScriptCommonConfig;
        primitives: {
            String: string;
            Int: string;
            Float: string;
            Boolean: string;
            ID: string;
        };
        types: import("graphql-codegen-core").Type[];
        inputTypes: import("graphql-codegen-core").Type[];
        enums: import("graphql-codegen-core").Enum[];
        unions: import("graphql-codegen-core").Union[];
        interfaces: import("graphql-codegen-core").Interface[];
        scalars: import("graphql-codegen-core").Scalar[];
        definedDirectives: import("graphql-codegen-core").Directive[];
        hasTypes: boolean;
        hasInputTypes: boolean;
        hasEnums: boolean;
        hasUnions: boolean;
        hasScalars: boolean;
        hasInterfaces: boolean;
        hasDefinedDirectives: boolean;
        rawSchema: GraphQLSchema;
        directives: import("graphql-codegen-core").DirectiveUseMap;
        usesDirectives: boolean;
    };
    convert: (str: string, kind?: "default" | "enumValues" | "typeNames") => string;
    scalars: {
        String: string;
        Int: string;
        Float: string;
        Boolean: string;
        ID: string;
    };
};
export declare const plugin: PluginFunction<TypeScriptCommonConfig>;
